# Slides Viewer

Viewer for live presentations, based on [manim-presentation](https://github.com/galatolofederico/manim-presentation) *for now*.



### License

The code is released as Free Software under the [GPLv3](https://www.gnu.org/licenses/gpl-3.0.html) license.